//
// Purpose:
//		This script assigns sequential numbers (1,2,3...) to assemblies/cast-units with the same ass.-/CU-number. 
//		The number is stored in a user defined attribute (e.g. "comment").
//
//		To assign the numbers this script will
//			1) Update numbering
//			2) Creates a report including needed data of selected assemblies/cast-units
//			3) Creates a file containing main-part ID and the sequential numbers
//			4) Imports the attributes (sequential number) by using the attribute import
//
//		Version: 02/11/2009

using System;
using System.IO;


namespace Tekla.Technology.Akit.UserScript
{
	public class Script
	{
		// These constants can be changed if neccesary
		//---------------------------------------------------------------
		const int StartNumber = 1;
		const int StepValue = 1;
		const string RebarSeqNoUDAName = @"ACN";
		//---------------------------------------------------------------
		const string DirectoryReports = @".\Lijsten\";
		const string ReportTemplate = @"sequencerassembly";
		const string OutFileName = @"sequencerassembly.txt";
		//---------------------------------------------------------------			

		public static void Run(Tekla.Technology.Akit.IScript akit)
		{
			string ReportFile = @DirectoryReports  + ReportTemplate + ".xsr";
			
			akit.Callback("acmd_partnumbers_all", "", "main_frame");
			akit.Callback("acmd_display_report_dialog", "", "main_frame");
			akit.ListSelect("xs_report_dialog", "xs_report_list", ReportTemplate);
			akit.ValueChange("xs_report_dialog", "display_created_report", "0");
			akit.ModalDialog(1);
			//akit.PushButton("xs_report_all", "xs_report_dialog");
			akit.PushButton("xs_report_selected", "xs_report_dialog");
			akit.PushButton("xs_report_cancel", "xs_report_dialog");
			akit.CommandEnd();
			
			CreateNumberFile(ReportFile, OutFileName, StartNumber, StepValue);

			akit.CommandStart("ail_create_macro", "10000015", "main_frame");
			akit.ValueChange("macro_10000015", "filename", OutFileName);
			akit.ValueChange("macro_10000015", "input_file_delimiters", "0");
			akit.ValueChange("macro_10000015", "user_defined_delimiter", "");
			akit.ValueChange("macro_10000015", "input_scope", "0");
			akit.ValueChange("macro_10000015", "create_log_file", "0");
			akit.ValueChange("macro_10000015", "display_log_file", "1");
			akit.PushButton("create_button", "macro_10000015");
			akit.PushButton("CANCEL_button", "macro_10000015");
		}

		static void CreateNumberFile(string InFileName, string OutFileName, int StartNr, int StepVal)
		{
			using(StreamWriter sw = new StreamWriter(OutFileName))
			{
				sw.WriteLine("ID\t" + RebarSeqNoUDAName);
				//sw.WriteLine("ID\t" + "comment");
				using (StreamReader sr = new StreamReader(InFileName)) 
				{
					string line;
					string [] aFields = null;
					string AssPos = "";
					int    partID = 0;
					//int    Counter = 0;
					int    AssNumber = 0;

					while ((line = sr.ReadLine()) != null) 
					{
						aFields = line.Split(';');
						int i1 = 0;
						foreach(string s in aFields)
						{
							if(i1 == 0)
							{
								try
								{
									partID = Convert.ToInt32(s);
								}
								catch (Exception e) { break; }
							}
							else if (i1 == 1 && s != AssPos)
							{
								AssPos = s;
								AssNumber = StartNr;
							}
							else if(i1 == 1 && s == AssPos)
							{
								AssNumber = AssNumber + StepVal;
							}

							if(i1 == 2)
							{
								sw.WriteLine(partID + "\t" + AssNumber);
								break;
							}
							++i1;
						}
					}
				}
			}
		}
	}
}
