//
// Purpose:
//		This script assigns sequential letters (a,b,c...) to reinforcement bars. 
//		The number is stored in a user defined attribute (REBAR_SEQ_LT) and the numbers are
//		unique for similar reinforcement barsshapes in each cast unit mark (=unit having same position)
//
//		To assign the numbers this script will
//			1) Update numbering
//			2) Imports the attributes (sequential letter) by using the attribute import


using System;
using System.IO;
using System.Windows.Forms;
using TS = Tekla.Structures;
using TSM = Tekla.Structures.Model;
using System.Collections.Generic;

namespace Tekla.Technology.Akit.UserScript
{
    public class Script
    {
        public static void Run(Tekla.Technology.Akit.IScript akit)
        {
            akit.Callback("acmd_partnumbers_all", "", "main_frame");
            TSM.Model model = new TSM.Model();

            TSM.ModelObjectEnumerator moe = model.GetModelObjectSelector().GetAllObjects();

            List<Tuple<string, string, string, int>> rebarDataList = new List<Tuple<string, string, string, int>>();

            while (moe.MoveNext())
            {
                try
                {
                    TSM.Reinforcement rebar = moe.Current as TSM.Reinforcement;

                    if (rebar != null)
                    {
                        string rebarPos = "", castUnitPos = "", rebarShape = "";

                        rebar.GetReportProperty("SHAPE", ref rebarShape);
                        rebar.GetReportProperty("REBAR_POS", ref rebarPos);
                        rebar.GetReportProperty("CAST_UNIT_POS", ref castUnitPos);

                        rebarDataList.Add(new Tuple<string, string, string, int>(castUnitPos, rebarShape, rebarPos, rebar.Identifier.ID));
                    }
                }
                catch
                {
                }
            }

            rebarDataList.Sort();

            WriteUDA(rebarDataList, model);
        }

        public static void WriteUDA(List<Tuple<string, string, string, int>> rebarDataList, TSM.Model model)
        {
            int rebarNo = -1, rebarNoToWrite = -1;
            string charsString = "", actualShapeType = "", actualRebarNo = "", actualCastUnit = "", stringToWrite = "";
            TS.TeklaStructuresSettings.GetAdvancedOption("XS_VALID_CHARS_FOR_ASSEMBLY_POSITION_NUMBERS", ref charsString);

            if (charsString.Length == 0)
            {
                charsString = "abcdfghjklmprstuwxyz";
            }
            else
            {
                charsString = charsString.ToLower();
            }

            for (int i = 0; i < rebarDataList.Count; i++)
            {
                if (rebarDataList[i].Item2 == actualShapeType)//same shape of bar
                {
                    if (rebarDataList[i].Item3 != actualRebarNo)//same shape but another RebarNo
                    {
                        rebarNo++;
                        actualRebarNo = rebarDataList[i].Item3;
                    }
                }
                else //new bar type
                {
                    actualShapeType = rebarDataList[i].Item2;
                    actualRebarNo = rebarDataList[i].Item3;
                    rebarNo = 0;
                }

                if (rebarDataList[i].Item1 != actualCastUnit) //new cast unit
                {
                    actualCastUnit = rebarDataList[i].Item1;
                    rebarNo = 0;
                }

                TSM.ModelObject rebarObject = model.SelectModelObject(new TS.Identifier(rebarDataList[i].Item4));

                rebarNoToWrite = rebarNo;
                stringToWrite = "";

                do //if NO is to high - more letters used..a, b, c, .... z, aa, ab, ... aaa, ...
                {
                    stringToWrite = charsString.Substring(rebarNoToWrite % charsString.Length, 1) + stringToWrite;
                    rebarNoToWrite = (rebarNoToWrite  / charsString.Length) - 1;
                }
                while (rebarNoToWrite >= 0);

                rebarObject.SetUserProperty("REBAR_SEQ_LT", stringToWrite);
            }
        }
    }
}
